package com.yijia.coupon.controller;
import java.util.Arrays;
import java.util.List;
import com.yijia.common.core.domain.model.LoginUser;
import com.yijia.common.utils.SecurityUtils;
import com.yijia.coupon.domain.CouponIssueRelation;
import com.yijia.coupon.service.ICouponIssueRelationService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yijia.common.annotation.Log;
import com.yijia.common.core.controller.BaseController;
import com.yijia.common.core.domain.AjaxResult;
import com.yijia.common.enums.BusinessType;
import com.yijia.coupon.domain.CouponIssue;
import com.yijia.coupon.service.ICouponIssueService;
import com.yijia.common.utils.poi.ExcelUtil;
import com.yijia.common.core.page.TableDataInfo;

/**
 * 优惠劵发放方式Controller
 * @author yijia
 * @date 2021-08-13
 */
@RestController
@RequestMapping("/coupon/issue")
public class CouponIssueController extends BaseController
{
    @Autowired
    private ICouponIssueService couponIssueService;
    @Autowired
    private ICouponIssueRelationService couponIssueRelationService;
    /**
     * 查询优惠劵发放方式列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CouponIssue couponIssue)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        couponIssue.setStationId(currentUser.getUser().getDeptId());
        startPage();
        List<CouponIssue> list = couponIssueService.selectCouponIssueList(couponIssue);
        if(list!=null && list.size()>0){
            for(CouponIssue issue:list){
                if(issue!=null && issue.getShowId()!=null){
                    issue.setShowIdList(Arrays.asList(issue.getShowId().split(",")));
                }
                if(issue!=null && issue.getAppointedDays()!=null){
                    issue.setAppointedDaysList(Arrays.asList(issue.getAppointedDays().split(",")));
                }
                if(issue!=null && issue.getCycleDays()!=null){
                    issue.setCycleDaysList(Arrays.asList(issue.getCycleDays().split(",")));
                }
                CouponIssueRelation couponIssueRelation =new CouponIssueRelation();
                couponIssueRelation.setIssueId(issue.getId());
                List<Integer> detailList = couponIssueRelationService.selectCouponIdList(couponIssueRelation);
                if(detailList!=null &&detailList.size()>0){
                    issue.setCouponIssueRelationList(detailList);
                }
            }
        }
        return getDataTable(list);
    }

    /**
     * 导出优惠劵发放方式列表
     */
    @Log(title = "优惠劵发放方式", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(CouponIssue couponIssue)
    {
        List<CouponIssue> list = couponIssueService.selectCouponIssueList(couponIssue);
        ExcelUtil<CouponIssue> util = new ExcelUtil<CouponIssue>(CouponIssue.class);
        return util.exportExcel(list, "issue");
    }

    /**
     * 获取优惠劵发放方式详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        //查询优惠劵发放方式
        CouponIssue couponIssue = couponIssueService.selectCouponIssueById(id);
        if(couponIssue!=null ){
            //查询发放对应的优惠
            CouponIssueRelation relation =new CouponIssueRelation();
            relation.setCouponId(couponIssue.getId());
            if(couponIssue!=null && couponIssue.getShowId()!=null){
                couponIssue.setShowIdList(Arrays.asList(couponIssue.getShowId().split(",")));
            }
            if(couponIssue!=null && couponIssue.getAppointedDays()!=null){
                couponIssue.setAppointedDaysList(Arrays.asList(couponIssue.getAppointedDays().split(",")));
            }
            if(couponIssue!=null && couponIssue.getCycleDays()!=null){
                couponIssue.setCycleDaysList(Arrays.asList(couponIssue.getCycleDays().split(",")));
            }
            List<Integer>  list =  couponIssueRelationService.selectCouponIdList(relation);
            couponIssue.setCouponIssueRelationList(list);
        }
        return AjaxResult.success(couponIssue);
    }

    /**
     * 新增优惠劵发放方式
     */
    @Log(title = "优惠劵发放方式", businessType = BusinessType.INSERT)
    @PostMapping
    @Transactional
    public AjaxResult add(@RequestBody CouponIssue couponIssue)
    {
        int i=0;
        if(couponIssue!=null &&couponIssue.getShowIdList()!=null && couponIssue.getShowIdList().size()>0){
            String verification= StringUtils.join( couponIssue.getShowIdList(),",");
            couponIssue.setShowId(verification);
        }
        if(couponIssue!=null && couponIssue.getAppointedDaysList()!=null&&couponIssue.getAppointedDaysList().size()>0 ){
            couponIssue.setAppointedDays(StringUtils.join( couponIssue.getAppointedDaysList(),","));
        }
        if(couponIssue!=null && couponIssue.getCycleDaysList()!=null && couponIssue.getCycleDaysList().size()>0){
            couponIssue.setCycleDays(StringUtils.join( couponIssue.getCycleDaysList(),","));
        }
        LoginUser currentUser = SecurityUtils.getLoginUser();
        couponIssue.setCreateBy(String.valueOf(currentUser.getUser().getUserId()));
        i=couponIssueService.insertCouponIssue(couponIssue);
        List<Integer> list = couponIssue.getCouponIssueRelationList();
        if(list!=null && list.size()>0){
            for (Integer couponId : list){
                CouponIssueRelation issueRetail = new CouponIssueRelation();
                issueRetail.setIssueId(couponIssue.getId());
                issueRetail.setCouponId(Long.valueOf(couponId));
                issueRetail.setCreateBy(String.valueOf(currentUser.getUser().getUserId()));
                i=  couponIssueRelationService.insertCouponIssueRelation(issueRetail);
            }
        }
        return toAjax(i);
    }

    /**
     * 修改优惠劵发放方式
     */
    @Log(title = "优惠劵发放方式", businessType = BusinessType.UPDATE)
    @PutMapping
    @Transactional
    public AjaxResult edit(@RequestBody CouponIssue couponIssue)
    {
        int i=0;
        if(couponIssue!=null &&couponIssue.getShowIdList()!=null && couponIssue.getShowIdList().size()>0){
            String verification= StringUtils.join( couponIssue.getShowIdList(),",");
            couponIssue.setShowId(verification);
        }
        if(couponIssue!=null && couponIssue.getAppointedDays()!=null){
            couponIssue.setAppointedDaysList(Arrays.asList(couponIssue.getAppointedDays().split(",")));
        }
        if(couponIssue!=null && couponIssue.getCycleDays()!=null){
            couponIssue.setCycleDaysList(Arrays.asList(couponIssue.getCycleDays().split(",")));
        }
        LoginUser currentUser = SecurityUtils.getLoginUser();
        List<Integer> list = couponIssue.getCouponIssueRelationList();
        couponIssue.setUpdateBy(String.valueOf(currentUser.getUser().getUserId()));
        i=couponIssueService.updateCouponIssue(couponIssue);
        //删除所有的已绑定的优惠劵
        CouponIssueRelation detail = new CouponIssueRelation();
        detail.setIssueId(couponIssue.getId());
        i =  couponIssueRelationService.deleteCouponIssueRelation(detail);
        if(list!=null && list.size()>0){
            for (Integer couponId : list){
                CouponIssueRelation issueRetail = new CouponIssueRelation();
                issueRetail.setIssueId(couponIssue.getId());
                issueRetail.setCouponId(Long.valueOf(couponId));
                issueRetail.setCreateBy(String.valueOf(currentUser.getUser().getUserId()));
                i=  couponIssueRelationService.insertCouponIssueRelation(issueRetail);
            }
        }
        return toAjax(i);
    }

    @Log(title = "修改优惠劵发放方式状态", businessType = BusinessType.UPDATE)
    @PutMapping("/updateCouponIssueStatus")
    @Transactional
    public AjaxResult updateCouponIssueStatus(@RequestBody CouponIssue couponIssue)
    {
        int i=0;
        if(couponIssue!=null &&couponIssue.getShowIdList()!=null && couponIssue.getShowIdList().size()>0){
            String verification= StringUtils.join( couponIssue.getShowIdList(),",");
            couponIssue.setShowId(verification);
        }
        LoginUser currentUser = SecurityUtils.getLoginUser();
        couponIssue.setUpdateBy(String.valueOf(currentUser.getUser().getUserId()));
        i=couponIssueService.updateCouponIssue(couponIssue);
        return toAjax(i);
    }
    /**
     * 删除优惠劵发放方式
     */
    @Log(title = "优惠劵发放方式", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(couponIssueService.deleteCouponIssueByIds(ids));
    }
}
