package com.yijia.coupon.controller;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yijia.common.annotation.Log;
import com.yijia.common.core.controller.BaseController;
import com.yijia.common.core.domain.AjaxResult;
import com.yijia.common.enums.BusinessType;
import com.yijia.coupon.domain.CouponIssueRelation;
import com.yijia.coupon.service.ICouponIssueRelationService;
import com.yijia.common.utils.poi.ExcelUtil;
import com.yijia.common.core.page.TableDataInfo;

/**
 * 发放方式，优惠劵信息Controller
 *
 * @author yijia
 * @date 2021-08-13
 */
@RestController
@RequestMapping("/coupon/detail")
public class CouponIssueRelationController extends BaseController
{
    @Autowired
    private ICouponIssueRelationService couponIssueRelationService;

    /**
     * 查询发放方式，优惠劵信息列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CouponIssueRelation couponIssueRelation)
    {
        startPage();
        List<CouponIssueRelation> list = couponIssueRelationService.selectCouponIssueRelationList(couponIssueRelation);
        return getDataTable(list);
    }

    /**
     * 导出发放方式，优惠劵信息列表
     */
    @Log(title = "发放方式，优惠劵信息", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(CouponIssueRelation couponIssueRelation)
    {
        List<CouponIssueRelation> list = couponIssueRelationService.selectCouponIssueRelationList(couponIssueRelation);
        ExcelUtil<CouponIssueRelation> util = new ExcelUtil<CouponIssueRelation>(CouponIssueRelation.class);
        return util.exportExcel(list, "detail");
    }

    /**
     * 获取发放方式，优惠劵信息详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(couponIssueRelationService.selectCouponIssueRelationById(id));
    }

    /**
     * 新增发放方式，优惠劵信息
     */
    @Log(title = "发放方式，优惠劵信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CouponIssueRelation couponIssueRelation)
    {
        return toAjax(couponIssueRelationService.insertCouponIssueRelation(couponIssueRelation));
    }

    /**
     * 修改发放方式，优惠劵信息
     */
    @Log(title = "发放方式，优惠劵信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CouponIssueRelation couponIssueRelation)
    {
        return toAjax(couponIssueRelationService.updateCouponIssueRelation(couponIssueRelation));
    }

    /**
     * 删除发放方式，优惠劵信息
     */
    @Log(title = "发放方式，优惠劵信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(couponIssueRelationService.deleteCouponIssueRelationByIds(ids));
    }
}
