package com.yijia.coupon.domain;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonIgnore;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.yijia.common.annotation.Excel;
import com.yijia.common.core.domain.BaseEntity;

/**
 * 优惠劵对象 coupon_info
 *
 * @author yijia
 * @date 2021-08-09
 */
public class CouponInfo extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** $column.columnComment */
    private Integer id;

    /** 油站ID */
    @Excel(name = "油站ID")
    private Long stationId;

    /** 优惠劵名称 */
    @Excel(name = "优惠劵名称")
    private String couponName;

    /** 优惠劵类型 1现金劵，2折扣券，3兑换券 */
    @Excel(name = "优惠劵类型 1现金劵，2折扣券，3兑换券")
    private String couponType;

    /** 优惠券使用门槛金额 */
    @Excel(name = "优惠券使用门槛金额")
    private Long couponThresholdAmt;

    /** 优惠劵使用门槛类型。 1.无门槛，2满减劵，3折扣 */
    @Excel(name = "优惠劵使用门槛类型。 1.无门槛，2满减劵，3折扣")
    private String useDiscountType;

    /** 油品 */
    @Excel(name = "油品")
    private String oilName;

    /** 1 汽油，2 柴油，3非油品，4LNG 5 CNG */
    @Excel(name = "1 汽油，2 柴油，3非油品，4LNG 5 CNG")
    private String oilType;

    /** 优惠劵面值，金额，折扣比例 */
    @Excel(name = "优惠劵面值，金额，折扣比例")
    private BigDecimal couponAmt;

    /** 优惠劵数量 */
    @Excel(name = "优惠劵数量")
    private Integer couponNum;
    /** 优惠劵持有张数 */
    private Integer couponHoldNum;

    /** 有效时间类型： 1，固定时间；2，领取后x天内有效 */
    @Excel(name = "有效时间类型： 1，固定时间；2，领取后x天内有效")
    private String effectiveTimeType;

    /** 固定时间-有效开始时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "固定时间-有效开始时间", width = 30, dateFormat = "yyyy-MM-dd")
    private Date effectiveTimeStart;

    /** 固定时间-有效结束时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "固定时间-有效结束时间", width = 30, dateFormat = "yyyy-MM-dd")
    private Date effectiveTimeEnd;

    /** 有效天数 */
    @Excel(name = "有效天数")
    private Integer effectiveDayNum;

    /** 优惠劵领取数量 */
    @Excel(name = "优惠劵领取数量")
    private Integer couponReceiveNum;

    /**优惠劵累计领用数量*/
    private Integer couponCumulativeNum;
    /**优惠劵累计使用数量*/
    private Integer couponUseNum;

    /** 发放平台，1.微信 2支付宝 */
    @Excel(name = "发放平台，1.微信 2支付宝")
    private String openPlatform;

    /** 优惠内容*/
    private String couponDetails;

    /** 发放状态：0，未发放；1，已发放； */
    @Excel(name = "发放状态：0，未发放；1，已发放；")
    private String grantStatus;

    /** 有效状态：0，未生效； 1，生效；2，失效； */
    @Excel(name = "有效状态：0，未生效； 1，生效；2，失效；")
    private String status;

    /** 是否删除优惠劵 1是 0 否 */
    private String delFlag;
    /** 优惠劵 站点id **/
    private String verification;
    /**优惠卷站点id*/
    private List<Integer> verificationList;
    private List<String> oilNameList;
    /**是否开启电子卡*/
    private String isCardFlag;
    /**是否开启等级*/
    private String isGradeFlag;
    /**是否开启营销*/
    private String isMarketFlag;
    private String editFlag;
    private String appointedDays;
    private String cycleDays;
    private String availableControl;

    private List<String> appointedDaysList;
    private List<String> cycleDaysList;

    public List<String> getAppointedDaysList() {
        return appointedDaysList;
    }

    public void setAppointedDaysList(List<String> appointedDaysList) {
        this.appointedDaysList = appointedDaysList;
    }

    public List<String> getCycleDaysList() {
        return cycleDaysList;
    }

    public void setCycleDaysList(List<String> cycleDaysList) {
        this.cycleDaysList = cycleDaysList;
    }

    public String getAppointedDays() {
        return appointedDays;
    }

    public void setAppointedDays(String appointedDays) {
        this.appointedDays = appointedDays;
    }

    public String getCycleDays() {
        return cycleDays;
    }

    public void setCycleDays(String cycleDays) {
        this.cycleDays = cycleDays;
    }

    public String getAvailableControl() {
        return availableControl;
    }

    public void setAvailableControl(String availableControl) {
        this.availableControl = availableControl;
    }

    public String getEditFlag() {
        return editFlag;
    }

    public void setEditFlag(String editFlag) {
        this.editFlag = editFlag;
    }

    /**
     * 时间数组
     */
    private List<String> effectiveTime;

    public String getIsCardFlag() {
        return isCardFlag;
    }

    public void setIsCardFlag(String isCardFlag) {
        this.isCardFlag = isCardFlag;
    }

    public String getIsGradeFlag() {
        return isGradeFlag;
    }

    public void setIsGradeFlag(String isGradeFlag) {
        this.isGradeFlag = isGradeFlag;
    }

    public String getIsMarketFlag() {
        return isMarketFlag;
    }

    public void setIsMarketFlag(String isMarketFlag) {
        this.isMarketFlag = isMarketFlag;
    }

    public List<String> getEffectiveTime() {
        return effectiveTime;
    }

    public void setEffectiveTime(List<String> effectiveTime) {
        this.effectiveTime = effectiveTime;
    }

    public List<String> getOilNameList() {
        return oilNameList;
    }

    public void setOilNameList(List<String> oilNameList) {
        this.oilNameList = oilNameList;
    }

    public Integer getCouponCumulativeNum() {
        return couponCumulativeNum;
    }

    public void setCouponCumulativeNum(Integer couponCumulativeNum) {
        this.couponCumulativeNum = couponCumulativeNum;
    }

    public Integer getCouponUseNum() {
        return couponUseNum;
    }

    public void setCouponUseNum(Integer couponUseNum) {
        this.couponUseNum = couponUseNum;
    }

    public List<Integer> getVerificationList() {
        return verificationList;
    }

    public void setVerificationList(List<Integer> verificationList) {
        this.verificationList = verificationList;
    }

    public String getVerification() {
        return verification;
    }

    public void setVerification(String verification) {
        this.verification = verification;
    }

    public void setId(Integer id)
    {
        this.id = id;
    }

    public Integer getId()
    {
        return id;
    }

    public Integer getCouponNum() {
        return couponNum;
    }

    public void setCouponNum(Integer couponNum) {
        this.couponNum = couponNum;
    }

    public Integer getCouponHoldNum() {
        return couponHoldNum;
    }

    public void setCouponHoldNum(Integer couponHoldNum) {
        this.couponHoldNum = couponHoldNum;
    }

    public String getCouponDetails() {
        return couponDetails;
    }

    public void setCouponDetails(String couponDetails) {
        this.couponDetails = couponDetails;
    }

    public Long getStationId() {
        return stationId;
    }

    public void setStationId(Long stationId) {
        this.stationId = stationId;
    }

    public void setCouponName(String couponName)
    {
        this.couponName = couponName;
    }

    public String getCouponName()
    {
        return couponName;
    }
    public void setCouponType(String couponType)
    {
        this.couponType = couponType;
    }

    public String getCouponType()
    {
        return couponType;
    }
    public void setCouponThresholdAmt(Long couponThresholdAmt)
    {
        this.couponThresholdAmt = couponThresholdAmt;
    }

    public Long getCouponThresholdAmt()
    {
        return couponThresholdAmt;
    }
    public void setUseDiscountType(String useDiscountType)
    {
        this.useDiscountType = useDiscountType;
    }

    public String getUseDiscountType()
    {
        return useDiscountType;
    }
    public void setOilName(String oilName)
    {
        this.oilName = oilName;
    }

    public String getOilName()
    {
        return oilName;
    }
    public void setOilType(String oilType)
    {
        this.oilType = oilType;
    }

    public String getOilType()
    {
        return oilType;
    }
    public void setCouponAmt(BigDecimal couponAmt)
    {
        this.couponAmt = couponAmt;
    }

    public BigDecimal getCouponAmt()
    {
        return couponAmt;
    }

    public void setEffectiveTimeType(String effectiveTimeType)
    {
        this.effectiveTimeType = effectiveTimeType;
    }

    public String getEffectiveTimeType()
    {
        return effectiveTimeType;
    }
    public void setEffectiveTimeStart(Date effectiveTimeStart)
    {
        this.effectiveTimeStart = effectiveTimeStart;
    }

    public Date getEffectiveTimeStart()
    {
        return effectiveTimeStart;
    }
    public void setEffectiveTimeEnd(Date effectiveTimeEnd)
    {
        this.effectiveTimeEnd = effectiveTimeEnd;
    }

    public Date getEffectiveTimeEnd()
    {
        return effectiveTimeEnd;
    }
    public void setEffectiveDayNum(Integer effectiveDayNum)
    {
        this.effectiveDayNum = effectiveDayNum;
    }

    public Integer getEffectiveDayNum()
    {
        return effectiveDayNum;
    }
    public void setCouponReceiveNum(Integer couponReceiveNum)
    {
        this.couponReceiveNum = couponReceiveNum;
    }

    public Integer getCouponReceiveNum()
    {
        return couponReceiveNum;
    }
    public void setOpenPlatform(String openPlatform)
    {
        this.openPlatform = openPlatform;
    }

    public String getOpenPlatform()
    {
        return openPlatform;
    }
    public void setGrantStatus(String grantStatus)
    {
        this.grantStatus = grantStatus;
    }

    public String getGrantStatus()
    {
        return grantStatus;
    }
    public void setStatus(String status)
    {
        this.status = status;
    }

    public String getStatus()
    {
        return status;
    }
    public void setDelFlag(String delFlag)
    {
        this.delFlag = delFlag;
    }

    public String getDelFlag()
    {
        return delFlag;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this,ToStringStyle.MULTI_LINE_STYLE)
            .append("id", getId())
            .append("stationId", getStationId())
            .append("couponName", getCouponName())
            .append("couponType", getCouponType())
            .append("couponThresholdAmt", getCouponThresholdAmt())
            .append("useDiscountType", getUseDiscountType())
            .append("oilName", getOilName())
            .append("oilType", getOilType())
            .append("couponAmt",getCouponAmt())
            .append("couponNum",getCouponNum())
            .append("effectiveTimeType", getEffectiveTimeType())
            .append("effectiveTimeStart", getEffectiveTimeStart())
            .append("effectiveTimeEnd", getEffectiveTimeEnd())
            .append("effectiveDayNum", getEffectiveDayNum())
            .append("couponReceiveNum", getCouponReceiveNum())
            .append("openPlatform", getOpenPlatform())
            .append("grantStatus", getGrantStatus())
            .append("status", getStatus())
            .append("createBy", getCreateBy())
            .append("createTime", getCreateTime())
            .append("updateBy", getUpdateBy())
            .append("updateTime", getUpdateTime())
            .append("delFlag", getDelFlag())
            .append("verification", getVerification())
            .toString();
    }
}
