package com.yijia.coupon.service.impl;

import java.util.List;
import com.yijia.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yijia.coupon.mapper.CouponIssueMapper;
import com.yijia.coupon.domain.CouponIssue;
import com.yijia.coupon.service.ICouponIssueService;

/**
 * 优惠劵发放方式Service业务层处理
 * 
 * @author yijia
 * @date 2021-08-13
 */
@Service
public class CouponIssueServiceImpl implements ICouponIssueService 
{
    @Autowired
    private CouponIssueMapper couponIssueMapper;

    /**
     * 查询优惠劵发放方式
     * 
     * @param id 优惠劵发放方式ID
     * @return 优惠劵发放方式
     */
    @Override
    public CouponIssue selectCouponIssueById(Integer id)
    {
        return couponIssueMapper.selectCouponIssueById(id);
    }

    /**
     * 查询优惠劵发放方式列表
     * 
     * @param couponIssue 优惠劵发放方式
     * @return 优惠劵发放方式
     */
    @Override
    public List<CouponIssue> selectCouponIssueList(CouponIssue couponIssue)
    {
        return couponIssueMapper.selectCouponIssueList(couponIssue);
    }

    /**
     * 新增优惠劵发放方式
     * 
     * @param couponIssue 优惠劵发放方式
     * @return 结果
     */
    @Override
    public int insertCouponIssue(CouponIssue couponIssue)
    {
        couponIssue.setCreateTime(DateUtils.getNowDate());
        return couponIssueMapper.insertCouponIssue(couponIssue);
    }

    /**
     * 修改优惠劵发放方式
     * 
     * @param couponIssue 优惠劵发放方式
     * @return 结果
     */
    @Override
    public int updateCouponIssue(CouponIssue couponIssue)
    {
        couponIssue.setUpdateTime(DateUtils.getNowDate());
        return couponIssueMapper.updateCouponIssue(couponIssue);
    }

    /**
     * 批量删除优惠劵发放方式
     * 
     * @param ids 需要删除的优惠劵发放方式ID
     * @return 结果
     */
    @Override
    public int deleteCouponIssueByIds(Integer[] ids)
    {
        return couponIssueMapper.deleteCouponIssueByIds(ids);
    }

    /**
     * 删除优惠劵发放方式信息
     * 
     * @param id 优惠劵发放方式ID
     * @return 结果
     */
    @Override
    public int deleteCouponIssueById(Integer id)
    {
        return couponIssueMapper.deleteCouponIssueById(id);
    }
}
